@@ -2087,6 +2087,21 @@ class Group extends Error {
 		//
 		$this->addHistory(_('Added User'),$user_identifier);
 		db_commit();
+
+		//
+		// Update cache
+		//
+		$add_u = user_get_object($user_id);
+		$found = false;
+		foreach ($this->membersArr as $u) {
+			if ($u->getID() == $add_u->getID()) {
+				$found = true;
+				break;
+			}
+		}
+		if (!$found)
+			$this->membersArr[] = $add_u;
+
 		return true;
 	}
 
@@ -2200,6 +2215,18 @@ class Group extends Error {
 		$this->addHistory(_('Removed User'),$user_id);
 
 		db_commit();
+
+		//
+		// Update cache
+		//
+		$del_u = user_get_object($user_id);
+		foreach ($this->membersArr as $k => $u) {
+			if ($u->getID() == $del_u->getID()) {
+				unset($this->membersArr[$k]);
+				break;
+			}
+		}
+
 		return true;
 	}
 
@@ -2564,8 +2591,8 @@ class Group extends Error {
 			$params['id_mappings'] = $id_mappings;
 			plugin_hook_by_reference ('clone_project_from_template', $params);
 		} else {
-			// Disable everything
-			db_query_params ('UPDATE groups SET use_mail=0, use_survey=0, use_forum=0, use_pm=0, use_pm_depend_box=0, use_scm=0, use_news=0, use_docman=0, use_ftp=0, use_tracker=0, use_frs=0, use_stats=0 WHERE group_id=$1',
+			// Disable everything - except use_scm (manually set in the registration page)
+			db_query_params ('UPDATE groups SET use_mail=0, use_survey=0, use_forum=0, use_pm=0, use_pm_depend_box=0, use_news=0, use_docman=0, use_ftp=0, use_tracker=0, use_frs=0, use_stats=0 WHERE group_id=$1',
 				array($this->getID()));
 		}
 
